.. _reference:

Reference
=========

GeoTop
-------
.. autofunction:: bromodels.GTM.GeoTop.GeoTopDomain

.. autofunction:: bromodels.GTM.GeoTop.GeoTopColumn

.. autofunction:: bromodels.GTM.GeoTop.GeoTopPoint

.. autofunction:: bromodels.GTM.GeoTop.geotop_stratigraphic_unit

.. autofunction:: bromodels.GTM.GeoTop.geotop_lithology_class

REGIS
------
.. autofunction:: bromodels.HGM.Regis.RegisDomain

.. autofunction:: bromodels.HGM.Regis.RegisColumn

.. autofunction:: bromodels.HGM.Regis.RegisPoint

.. autofunction:: bromodels.HGM.Regis.regis_stratigraphic_unit

.. autofunction:: bromodels.HGM.Regis.dataset_fill
